/**********************************************************************
 * FaceBox - a Friendly HeadBot
 * based on SparkFun Red Box Robot
 * 
 * Dave Prochnow for SERVO Magazine
 * 15 Dec 2016
 * 
 * Parts list, assembly steps, and sample code 
 * available @ learn.sparkfun.com/tutorials/red-box-robot-hookup-guide
**********************************************************************/

#include <SparkFun_TB6612.h>

// these constants are used to allow you to make your motor configuration 
// line up with function names like forward. Value can be 1 or -1
const int offsetA = -1;
const int offsetB = -1;

// Pins for all inputs, keep in mind the PWM defines must be on PWM pins
// the default pins listed are the ones used on the Redbot (ROB-12097) with 
// the exception of STBY which the Redbot controls with a physical switch 
#define AIN1 2
#define AIN2 4
#define PWMA 10
#define STBY 9

// Initializing motors. The library will allow you to initialize as many 
// motors as you have memory for. If you are using functions like forward 
// that take 2 motors as arguements you can either write new functions or 
// call the function more than once.
Motor motor1 = Motor(AIN1, AIN2, PWMA, offsetA, STBY); 

// Rangefinder Pins
const int TRIG_PIN = 11; 
const int ECHO_PIN = 12;

// Anything over 400 cm (23200 us pulse) is out of range
const unsigned int MAX_DIST = 23200;

void setup() {
  // put your setup code here, to run once:

  // Setup all of our pins 
  pinMode(TRIG_PIN, OUTPUT); 
  digitalWrite(TRIG_PIN, LOW);

  pinMode(2, OUTPUT); digitalWrite(2, LOW);
  pinMode(4, OUTPUT); digitalWrite(4, LOW);
  pinMode(6, OUTPUT); 
// This pin is used for the speaker and the LED
  pinMode(A4, OUTPUT); 

}

void loop() {
  // put your main code here, to run repeatedly:

  // Start scanning
  // Use the drive function with arguments for speed and duration.
  // A negative speed with reverse direction. Speed range -255 to 255
  // The brake function will stop the motor.

  motor1.drive(50,2000);

  // Setup variables for rangefinder
  unsigned long t1;
  unsigned long t2;
  unsigned long pulse_width; 
  float cm;

  motor1.brake();

  // Hold the trigger pin high for at least 10 us
  digitalWrite(TRIG_PIN, HIGH); 
  delayMicroseconds(10); 
  digitalWrite(TRIG_PIN, LOW);

  // Wait for pulse on echo pin
  while ( digitalRead(ECHO_PIN) == 0 );
  
  // Measure how long the echo pin was held high (pulse width)
  // Note: the micros() counter will overflow after ~70 min 
  t1 = micros();
  while ( digitalRead(ECHO_PIN) == 1);
  t2 = micros();
  pulse_width = t2 - t1;
  
  // Calculate distance in centimeters. 
  cm = pulse_width / 58.0;
  
  // If an obstacle is detected fewer than 80 centimeters away,
  // engage the obstacle in social chit-chat
  if (cm < 80)
    {
      whistle();
      delay(1000);
      tone(A4, random(50,400)*10);
      delay(500);
      whistle();
    }
    
  motor1.drive(-50,2000);
  motor1.brake();
  delay(500);

}

// Make a series of cute random beeping sounds 
int whistle(){
tone(A4,random(50,400)*10);
delay(100);
tone(A4,random(50,400)*10); 
delay(100); 
tone(A4,random(50,400)*10); 
delay(100); 
tone(A4,random(50,400)*10); 
delay(100); 
tone(A4,random(50,400)*10); 
delay(100); 
tone(A4,random(50,400)*10); 
delay(100); 
tone(A4,random(50,400)*10); 
delay(100); 
tone(A4,random(50,400)*10); 
delay(100);
noTone(A4); 
delay(100); 
}
